# Changelog

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [Unreleased]

- Change PyPI name to `balsamish` in response to this issue:
  https://github.com/pypa/pypi-support/issues/1483

## [0.7.0] - 2019-06-27

### Changes

- Dictionary in schema is nullable when not required
